==> pixi-0.60.0-crates.tar.xz: cargo_home/gentoo/rattler_macros-1.0.11/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.11](https://github.com/conda/rattler/compare/rattler_macros-v1.0.10...rattler_macros-v1.0.11) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [1.0.10](https://github.com/conda/rattler/compare/rattler_macros-v1.0.9...rattler_macros-v1.0.10) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [1.0.9](https://github.com/conda/rattler/compare/rattler_macros-v1.0.8...rattler_macros-v1.0.9) - 2025-05-16

### Other

- update Cargo.toml dependencies

## [1.0.8](https://github.com/conda/rattler/compare/rattler_macros-v1.0.7...rattler_macros-v1.0.8) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [1.0.7](https://github.com/conda/rattler/compare/rattler_macros-v1.0.6...rattler_macros-v1.0.7) - 2025-03-10

### Other

- update Cargo.toml dependencies

## [1.0.6](https://github.com/conda/rattler/compare/rattler_macros-v1.0.5...rattler_macros-v1.0.6) - 2025-02-18

### Other

- update Cargo.toml dependencies

## [1.0.5](https://github.com/conda/rattler/compare/rattler_macros-v1.0.4...rattler_macros-v1.0.5) - 2025-01-08

### Other

- update Cargo.toml dependencies

## [1.0.4](https://github.com/conda/rattler/compare/rattler_macros-v1.0.3...rattler_macros-v1.0.4) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [1.0.3](https://github.com/conda/rattler/compare/rattler_macros-v1.0.2...rattler_macros-v1.0.3) - 2024-11-04

### Other

- update Cargo.toml dependencies

## [1.0.2](https://github.com/conda/rattler/compare/rattler_macros-v1.0.1...rattler_macros-v1.0.2) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.0.1](https://github.com/conda/rattler/compare/rattler_macros-v1.0.0...rattler_macros-v1.0.1) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.19.4](https://github.com/conda/rattler/compare/rattler_macros-v0.19.3...rattler_macros-v0.19.4) - 2024-07-08

### Other
- update README.md

## [0.19.3](https://github.com/conda/rattler/compare/rattler_macros-v0.19.2...rattler_macros-v0.19.3) - 2024-04-19

### Other
- update Cargo.toml dependencies

## [0.19.2](https://github.com/conda/rattler/compare/rattler_macros-v0.19.1...rattler_macros-v0.19.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.1](https://github.com/conda/rattler/compare/rattler_macros-v0.19.0...rattler_macros-v0.19.1) - 2024-03-06

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_macros-v0.18.0...rattler_macros-v0.19.0) - 2024-02-26

==> pixi-0.63.2-crates.tar.xz: cargo_home/gentoo/rattler_macros-1.0.12/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.12](https://github.com/conda/rattler/compare/rattler_macros-v1.0.11...rattler_macros-v1.0.12) - 2025-12-18

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [1.0.11](https://github.com/conda/rattler/compare/rattler_macros-v1.0.10...rattler_macros-v1.0.11) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [1.0.10](https://github.com/conda/rattler/compare/rattler_macros-v1.0.9...rattler_macros-v1.0.10) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [1.0.9](https://github.com/conda/rattler/compare/rattler_macros-v1.0.8...rattler_macros-v1.0.9) - 2025-05-16

### Other

- update Cargo.toml dependencies

## [1.0.8](https://github.com/conda/rattler/compare/rattler_macros-v1.0.7...rattler_macros-v1.0.8) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [1.0.7](https://github.com/conda/rattler/compare/rattler_macros-v1.0.6...rattler_macros-v1.0.7) - 2025-03-10

### Other

- update Cargo.toml dependencies

## [1.0.6](https://github.com/conda/rattler/compare/rattler_macros-v1.0.5...rattler_macros-v1.0.6) - 2025-02-18

### Other

- update Cargo.toml dependencies

## [1.0.5](https://github.com/conda/rattler/compare/rattler_macros-v1.0.4...rattler_macros-v1.0.5) - 2025-01-08

### Other

- update Cargo.toml dependencies

## [1.0.4](https://github.com/conda/rattler/compare/rattler_macros-v1.0.3...rattler_macros-v1.0.4) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [1.0.3](https://github.com/conda/rattler/compare/rattler_macros-v1.0.2...rattler_macros-v1.0.3) - 2024-11-04

### Other

- update Cargo.toml dependencies

## [1.0.2](https://github.com/conda/rattler/compare/rattler_macros-v1.0.1...rattler_macros-v1.0.2) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.0.1](https://github.com/conda/rattler/compare/rattler_macros-v1.0.0...rattler_macros-v1.0.1) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.19.4](https://github.com/conda/rattler/compare/rattler_macros-v0.19.3...rattler_macros-v0.19.4) - 2024-07-08

### Other
- update README.md

## [0.19.3](https://github.com/conda/rattler/compare/rattler_macros-v0.19.2...rattler_macros-v0.19.3) - 2024-04-19

### Other
- update Cargo.toml dependencies

## [0.19.2](https://github.com/conda/rattler/compare/rattler_macros-v0.19.1...rattler_macros-v0.19.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.1](https://github.com/conda/rattler/compare/rattler_macros-v0.19.0...rattler_macros-v0.19.1) - 2024-03-06

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_macros-v0.18.0...rattler_macros-v0.19.0) - 2024-02-26
